# Generated by Django 4.0.5 on 2022-06-25 06:34

from django.db import migrations, models
import uuid


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='ActivationToken',
            fields=[
                ('email', models.CharField(max_length=255, primary_key=True, serialize=False)),
                ('token', models.UUIDField(default=uuid.uuid4, editable=False, unique=True)),
                ('created', models.DateField(auto_now_add=True)),
            ],
        ),
    ]
